<template>
  <div class="mine-page-top-view">
    <slot name="avatar"></slot>
    <div class="setting-wrapper" v-if="showUserHomePageBtn" @click="">
      <div class="setting-text">
        我的简历<IconFont name="rect-right" size="16" color="#6D6E6E"></IconFont>
      </div>
    </div>
  </div>
</template>

<script setup lang="ts">
import { useUser } from '@/hooks';
import Taro from '@tarojs/taro';

defineOptions({
  name: 'UserHomeTopView',
});

type Props = {
  showUserHomePageBtn?: boolean;
  showOperation?: boolean;
};

const props = withDefaults(defineProps<Props>(), {
  showUserHomePageBtn: false,
  showOperation: false,
});

const { userDetail } = useUser();
</script>

<style lang="scss">
@import '@/styles/common.scss';

.mine-page-top-view {
  padding-top: 34px;
  display: flex;
  margin-bottom: 20px;

  .setting-wrapper {
    align-self: center;
    display: flex;
    align-items: center;
    margin-right: calc(boleGetCssVar('size', 'body-padding-h') * -1);

    .setting-text {
      font-weight: 400;
      font-size: 28px;
      display: flex;
      align-items: center;
      color: boleGetCssVar('text-color', 'primary');
      padding-right: 20px;
    }
  }
}

.mine-page-operation-wrapper {
  display: flex;
  padding-top: 22px;
  margin-bottom: 36px;

  .mine-page-operation-item {
    flex: 1;
    min-width: 0;
    align-items: center;
    display: flex;
    padding-left: 28px;
    border-right: 1px solid #efefef;

    &:last-child {
      border-right: none;
    }

    &.share {
      background-color: transparent;
      padding-right: 0;
      appearance: none;
      text-align: left;

      &::after {
        border: none;
      }
      /* .mine-page-operation-item-inner {
        display: flex;
        align-items: center;
      } */
    }

    .mine-page-operation-item-icon {
      width: 32px;
      height: 32px;
      margin-right: 8px;
    }

    .mine-page-operation-item-text {
      flex: 1;
      min-width: 0;
      font-weight: bold;
      font-size: 24px;
      color: boleGetCssVar('text-color', 'primary');
      line-height: 34px;
    }

    .mine-page-operation-item-arrow {
      width: 28px;
      height: 28px;
      margin-right: 28px;
    }
  }
}
</style>
